@@ -40,9 +40,9 @@ copyright = '2008, SymPy Development Team'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '0.6.1'
+version = '0.6.3'
 # The full version, including alpha/beta/rc tags.
-release = '0.6.1'
+release = '0.6.3'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
@@ -79,12 +79,14 @@ html_style = 'default.css'
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['.static']
+html_static_path = ['_static']
 
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
 html_last_updated_fmt = '%b %d, %Y'
 
+html_logo = '_static/sympylogo.png'
+
 # If true, SmartyPants will be used to convert quotes and dashes to
 # typographically correct entities.
 #html_use_smartypants = True
