@@ -13,7 +13,8 @@ $ python examples/fem_test.py
 [-1/360, -1/90, -1/360,     0,     0,   1/60]
 """
 
-from fem import *
+from sympy import Symbol, zeros, diff, pprint
+from fem import ReferenceSimplex, Lagrange
 
 t = ReferenceSimplex(2)
 fe = Lagrange(2,2)
@@ -27,7 +28,7 @@ for i in range(0, fe.nbf()):
    u += ui*fe.N[i]
 
 
-J = zeronm(fe.nbf(), fe.nbf())
+J = zeros(fe.nbf())
 for i in range(0, fe.nbf()):
    Fi = u*fe.N[i]
    for j in range(0, fe.nbf()):
