@@ -10,7 +10,7 @@ See the webpage for more information and documentation:
     http://code.google.com/p/sympy/
 """
 
-__version__ = "0.6.1"
+__version__ = "0.6.3"
 
 import symbol as stdlib_symbol
 from sympy.core import *
@@ -31,9 +31,11 @@ from integrals import *
 from plotting import Plot, textplot
 from printing import pretty, pretty_print, pprint, pprint_use_unicode, \
     pprint_try_use_unicode, print_gtk, print_tree
-from printing import latex, preview, view, pngview, pdfview, dviview
-from printing import python, print_python
+from printing import ccode, latex, preview, view, pngview, pdfview, dviview
+from printing import python, print_python, srepr, sstr, sstrrepr
 from polynomials import factor
 
+evalf._create_evalf_table()
+
 # This is slow to import:
 #import abc
