@@ -23,25 +23,27 @@ Example:
     >>> x = Symbol("x")
     >>> f(x)
     f(x)
-    >>> f(x).func
-    <class 'sympy.core.function.f'>
+    >>> print srepr(f(x).func)
+    Function('f')
     >>> f(x).args
     (x,)
 """
 
-from basic import Basic, Singleton, Atom, S, C, sympify
+from basic import Basic, Atom, S, C, sympify
 from basic import BasicType, BasicMeta
-from methods import ArithMeths, RelMeths
 from operations import AssocOp
 from cache import cacheit
 from itertools import repeat
-from numbers import Rational,Integer
+from numbers import Rational, Integer
 from symbol import Symbol
 from add    import Add
 from multidimensional import vectorize
 
 from sympy import mpmath
 
+class PoleError(Exception):
+    pass
+
 class FunctionClass(BasicMeta):
     """
     Base class for function classes. FunctionClass is a subclass of type.
@@ -55,6 +57,13 @@ class FunctionClass(BasicMeta):
     def __new__(cls, arg1, arg2, arg3=None, **options):
         assert not options,`options`
         if isinstance(arg1, type):
+            # the following code gets executed when one types
+            # FunctionClass(Function, "f")
+            # i.e. cls = FunctionClass, arg1 = Function, arg2 = "f"
+            # and we simply do an equivalent of:
+            # class f(Function):
+            #     ...
+            # return f
             ftype, name, signature = arg1, arg2, arg3
             #XXX this probably needs some fixing:
             assert ftype.__name__.endswith('Function'),`ftype`
@@ -68,10 +77,10 @@ class FunctionClass(BasicMeta):
             name, bases, attrdict = arg1, arg2, arg3
             return type.__new__(cls, name, bases, attrdict)
 
-    def torepr(cls):
+    def __repr__(cls):
         return cls.__name__
 
-class Function(Basic, ArithMeths, RelMeths):
+class Function(Basic):
     """
     Base class for applied functions.
     Constructor of undefined classes.
@@ -82,8 +91,6 @@ class Function(Basic, ArithMeths, RelMeths):
 
     is_Function = True
 
-    precedence = Basic.Apply_precedence
-
     nargs = None
 
     @vectorize(1)
@@ -130,10 +137,15 @@ class Function(Basic, ArithMeths, RelMeths):
         # up to here.
         if options.get('evaluate') is False:
             return Basic.__new__(cls, *args, **options)
-        r = cls.canonize(*args, **options)
+        r = cls.canonize(*args)
         if isinstance(r, Basic):
             return r
         elif r is None:
+            # Just undefined functions have nargs == None
+            if not cls.nargs and hasattr(cls, 'undefined_Function'):
+                r = Basic.__new__(cls, *args, **options)
+                r.nargs = len(args)
+                return r
             pass
         elif not isinstance(r, tuple):
             args = (r,)
@@ -144,7 +156,7 @@ class Function(Basic, ArithMeths, RelMeths):
         return True
 
     @classmethod
-    def canonize(cls, *args, **options):
+    def canonize(cls, *args):
         """
         Returns a canonical form of cls applied to arguments args.
 
@@ -178,9 +190,13 @@ class Function(Basic, ArithMeths, RelMeths):
     def _eval_subs(self, old, new):
         if self == old:
             return new
-        elif isinstance(old, FunctionClass) and isinstance(new, FunctionClass):
-            if old == self.func and old.nargs == new.nargs:
-                return new(*self.args[:])
+        elif old.is_Function and new.is_Function:
+            if old == self.func:
+                if self.nargs is new.nargs or not new.nargs:
+                    return new(*self.args[:])
+                # Written down as an elif to avoid a super-long line
+                elif isinstance(new.nargs,tuple) and self.nargs in new.nargs:
+                    return new(*self.args[:])
         obj = self.func._eval_apply_subs(*(self.args[:] + (old,) + (new,)))
         if obj is not None:
             return obj
@@ -264,13 +280,13 @@ class Function(Basic, ArithMeths, RelMeths):
         #      f()             args
         return 1   + Add(*[t.count_ops(symbolic) for t in self.args])
 
-    def _eval_oseries(self, order):
-        assert self.func.nargs==1,`self.func`
+    def _eval_nseries(self, x, x0, n):
+        assert len(self.args) == 1
         arg = self.args[0]
-        x = order.symbols[0]
-        if not C.Order(1,x).contains(arg):
-            return self.func(arg)
         arg0 = arg.limit(x, 0)
+        from sympy import oo
+        if arg0 in [-oo, oo]:
+            raise PoleError("Cannot expand around %s" % (arg))
         if arg0 is not S.Zero:
             e = self.func(arg)
             e1 = e.expand()
@@ -278,23 +294,24 @@ class Function(Basic, ArithMeths, RelMeths):
                 #for example when e = sin(x+1) or e = sin(cos(x))
                 #let's try the general algorithm
                 term = e.subs(x, S.Zero)
-                series = S.Zero
+                series = term
                 fact = S.One
-                i = 0
-                while not order.contains(term) or term == 0:
-                    series += term
+                for i in range(n-1):
                     i += 1
                     fact *= Rational(i)
                     e = e.diff(x)
                     term = e.subs(x, S.Zero)*(x**i)/fact
-                return series
-
-                #print '%s(%s).oseries(%s) is unevaluated' % (self.func,arg,order)
-            return e1.oseries(order)
-        return self._compute_oseries(arg, order, self.func.taylor_term, self.func)
-
-    def nseries(self, x, x0, n):
-        return self.series(x, x0, n)
+                    term = term.expand()
+                    series += term
+                return series + C.Order(x**n, x)
+            return self.nseries(x, x0, n)
+        l = []
+        g = None
+        for i in xrange(n+2):
+            g = self.taylor_term(i, arg, g)
+            g = g.nseries(x, x0, n)
+            l.append(g)
+        return Add(*l) + C.Order(x**n, x)
 
     def _eval_is_polynomial(self, syms):
         for arg in self.args:
@@ -331,19 +348,6 @@ class Function(Basic, ArithMeths, RelMeths):
                 raise TypeError("argument index %r is out of range [1,%s]" % (argindex,nargs))
         return Derivative(self,self.args[argindex-1],evaluate=False)
 
-    def torepr(self):
-        r = '%s(%r)' % (self.func.__base__.__name__, self.func.__name__)
-        r+= '(%s)' % ', '.join([a.torepr() for a in self.args])
-        return r
-
-    def tostr(self, level=0):
-        p = self.precedence
-        r = '%s(%s)' % (self.func.__name__, ', '.join([a.tostr() for a in
-            self.args]))
-        if p <= level:
-            return '(%s)' % (r)
-        return r
-
     @classmethod
     def _eval_apply_evalf(cls, arg):
         arg = arg.evalf(prec)
@@ -402,12 +406,6 @@ class WildFunction(Function, Atom):
         repl_dict[pattern] = expr
         return repl_dict
 
-    def torepr(self):
-        return '%s(%r)' % (self.__class__.__name__, self.name)
-
-    def tostr(self, level=0):
-        return self.name + '_'
-
     @classmethod
     def _eval_apply_evalf(cls, arg):
         return
@@ -416,7 +414,7 @@ class WildFunction(Function, Atom):
     def is_number(self):
         return False
 
-class Derivative(Basic, ArithMeths, RelMeths):
+class Derivative(Basic):
     """
     Carries out differentation of the given expression with respect to symbols.
 
@@ -429,7 +427,7 @@ class Derivative(Basic, ArithMeths, RelMeths):
     Derivative(expr, x, 3)  -> Derivative(expr, x, x, x)
     """
 
-    precedence = Basic.Apply_precedence
+    is_Derivative   = True
 
     @staticmethod
     def _symbolgen(*symbols):
@@ -470,20 +468,21 @@ class Derivative(Basic, ArithMeths, RelMeths):
         expr = sympify(expr)
         if not symbols: return expr
         symbols = Derivative._symbolgen(*symbols)
-        if not assumptions.get("evaluate", False):
+        if not assumptions.get("evaluate", False) and not isinstance(expr, Derivative):
             obj = Basic.__new__(cls, expr, *symbols)
             return obj
         unevaluated_symbols = []
         for s in symbols:
             s = sympify(s)
-            assert isinstance(s, Symbol),`s`
+            if not isinstance(s, Symbol):
+                raise ValueError('Invalid literal: %s is not a valid variable' % s)
             if not expr.has(s):
                 return S.Zero
             obj = expr._eval_derivative(s)
             if obj is None:
                 unevaluated_symbols.append(s)
             elif obj is S.Zero:
-                return expr
+                return S.Zero
             else:
                 expr = obj
 
@@ -514,14 +513,10 @@ class Derivative(Basic, ArithMeths, RelMeths):
     def symbols(self):
         return self._args[1:]
 
-    def tostr(self, level=0):
-        r = 'D' + `tuple(self.args)`
-        if self.precedence <= level:
-            r = '(%s)' % (r)
-        return r
-
     def _eval_subs(self, old, new):
-        return Derivative(self.args[0].subs(old, new), *self.args[1:], **{'evaluate': True})
+        if self==old:
+            return new
+        return Derivative(self.args[0]._eval_subs(old, new), *self.args[1:], **{'evaluate': True})
 
     def matches(pattern, expr, repl_dict={}, evaluate=False):
         # this method needs a cleanup.
@@ -549,6 +544,23 @@ class Derivative(Basic, ArithMeths, RelMeths):
         repl_dict[pattern] = expr
         return repl_dict
 
+    def _eval_lseries(self, x, x0):
+        stop
+        arg = self.args[0]
+        dx = self.args[1]
+        for term in arg.lseries(x, x0):
+            yield term.diff(dx)
+
+    def _eval_nseries(self, x, x0, n):
+        arg = self.args[0]
+        arg = arg.nseries(x, x0, n)
+        o = arg.getO()
+        dx = self.args[1]
+        if o:
+            return arg.removeO().diff(dx) + arg.getO()/dx
+        else:
+            return arg.removeO().diff(dx)
+
 class Lambda(Function):
     """
     Lambda(x, expr) represents a lambda function similar to Python's
@@ -593,24 +605,23 @@ class Lambda(Function):
     # a minimum of 2 arguments (parameter, expression) are needed
     nargs = 2
     def __new__(cls,*args):
-       # nargs = len(args)
         assert len(args) >= 2,"Must have at least one parameter and an expression"
         if len(args) == 2 and isinstance(args[0], (list, tuple)):
             args = tuple(args[0])+(args[1],)
         obj = Function.__new__(cls,*args)
-        obj.nargs = len(args)
+        obj.nargs = len(args)-1
         return obj
 
     @classmethod
     def canonize(cls,*args):
         obj = Basic.__new__(cls, *args)
         #use dummy variables internally, just to be sure
-        nargs = len(args)
+        nargs = len(args)-1
 
-        expression = args[nargs-1]
-        funargs = [Symbol(arg.name, dummy=True) for arg in args[:nargs-1]]
+        expression = args[nargs]
+        funargs = [Symbol(arg.name, dummy=True) for arg in args[:nargs]]
         #probably could use something like foldl here
-        for arg,funarg in zip(args[:nargs-1],funargs):
+        for arg,funarg in zip(args[:nargs],funargs):
             expression = expression.subs(arg,funarg)
         funargs.append(expression)
         obj._args = tuple(funargs)
@@ -637,12 +648,12 @@ class Lambda(Function):
 
         """
 
-        nparams = self.nargs - 1
+        nparams = self.nargs
         assert nparams >= len(args),"Cannot call function with more parameters than function variables: %s (%d variables) called with %d arguments" % (str(self),nparams,len(args))
 
 
         #replace arguments
-        expression = self.args[self.nargs-1]
+        expression = self.args[self.nargs]
         for arg,funarg in zip(args,self.args[:nparams]):
             expression = expression.subs(funarg,arg)
 
@@ -661,9 +672,9 @@ class Lambda(Function):
             if not len(self.args) == len(other.args):
                 return False
 
-            selfexpr = self.args[self.nargs-1]
-            otherexpr = other.args[other.nargs-1]
-            for selfarg,otherarg in zip(self.args[:self.nargs-1],other.args[:other.nargs-1]):
+            selfexpr = self.args[self.nargs]
+            otherexpr = other.args[other.nargs]
+            for selfarg,otherarg in zip(self.args[:self.nargs],other.args[:other.nargs]):
                 otherexpr = otherexpr.subs(otherarg,selfarg)
             if selfexpr == otherexpr:
                 return True
