@@ -1,7 +1,6 @@
 """sympify -- convert objects SymPy internal format"""
 # from basic import Basic, BasicType, S
 # from numbers  import Integer, Real
-# from interval import Interval
 import decimal
 
 class SympifyError(ValueError):
@@ -15,7 +14,7 @@ class SympifyError(ValueError):
         return "Sympify of expression '%s' failed, because of exception being raised:\n%s: %s" % (self.expr, self.base_exc.__class__.__name__, str(self.base_exc))
 
 
-def sympify(a, sympify_lists=False, locals= {}):
+def sympify(a, locals=None, convert_xor=True):
     """Converts an arbitrary expression to a type that can be used
        inside sympy. For example, it will convert python int's into
        instance of sympy.Rational, floats into intances of sympy.Real,
@@ -27,10 +26,6 @@ def sympify(a, sympify_lists=False, locals= {}):
            - standard numeric python types: int, long, float, Decimal
            - strings (like "0.09" or "2e-19")
 
-       If sympify_lists is set to True then sympify will also accept
-       lists, tuples and sets. It will return the same type but with
-       all of the entries sympified.
-
        If the argument is already a type that sympy understands, it will do
        nothing but return that value. This can be used at the begining of a
        function to ensure you are working with the correct type.
@@ -56,6 +51,8 @@ def sympify(a, sympify_lists=False, locals= {}):
     #
     # When everything settles, let's refactor this.
     #                                      -- kirr
+    if locals is None:
+        locals = {}
     if isinstance(a, Basic):
         return a
     if isinstance(a, BasicType):
@@ -73,11 +70,8 @@ def sympify(a, sympify_lists=False, locals= {}):
         return real + S.ImaginaryUnit * imag
     elif isinstance(a, bool):
         raise NotImplementedError("bool support")
-    elif (a.__class__ in [list,tuple]) and len(a) == 2:
-        # isinstance causes problems in the issue #432, so we use .__class__
-        return Interval(*a)
-    elif isinstance(a, (list,tuple,set)) and sympify_lists:
-        return type(a)([sympify(x, True) for x in a])
+    elif isinstance(a, (list,tuple,set)):
+        return type(a)([sympify(x) for x in a])
 
     # let's see if 'a' implements conversion methods such as '_sympy_' or
     # '__int__', that returns a SymPy (by definition) or SymPy compatible
@@ -121,11 +115,10 @@ def sympify(a, sympify_lists=False, locals= {}):
             # return an exception
             a = str(a)
 
-        try:
-            import ast_parser
-            return ast_parser.SymPyParser(local_dict=locals).parse_expr(a)
-        except Exception, exc:
-            raise SympifyError(a, exc)
+        if convert_xor:
+            a = a.replace('^','**')
+        import ast_parser
+        return ast_parser.parse_expr(a, locals)
     raise SympifyError("%r is NOT a valid SymPy expression" % a)
 
 
