@@ -1,9 +1,10 @@
-from sympy import Rational, Symbol, Real, I, sqrt, oo, nan, pi, Integer, \
+from sympy import Rational, Symbol, Real, I, sqrt, oo, nan, pi, E, Integer, \
         Basic, S
 from sympy.core.power import integer_nthroot
-import py
 
 from sympy.core.numbers import igcd, ilcm, igcdex
+from sympy.utilities.pytest import XFAIL, raises
+
 
 def test_igcd():
     assert igcd(0, 0) == 0
@@ -40,41 +41,18 @@ def test_igcdex():
     assert igcdex(10, 12) == (-1, 1, 2)
     assert igcdex(100, 2004) == (-20, 1, 4)
 
-def test_Rational():
-    n1 = Rational(1,4)
-    n2 = Rational(1,3)
-    n3 = Rational(2,4)
-    n4 = Rational(2,-4)
-    n5 = Rational(0)
-    n6 = Rational(1)
-    n7 = Rational(3)
-    n8 = Rational(-3)
-    assert str(n1*n2) == "1/12"
-    assert str(n1*n2) == "1/12"
-    assert str(n3) == "1/2"
-    assert str(n1*n3) == "1/8"
-    assert str(n1+n3) == "3/4"
-    assert str(n1+n2) == "7/12"
-    assert str(n1+n4) == "-1/4"
-    assert str(n4*n4) == "1/4"
-    assert str(n4+n2) == "-1/6"
-    assert str(n4+n5) == "-1/2"
-    assert str(n4*n5) == "0"
-    assert str(n3+n4) == "0"
-    assert str(n1**n7) == "1/64"
-    assert str(n2**n7) == "1/27"
-    assert str(n2**n8) == "27"
-    assert str(n7**n8) == "1/27"
-    assert str(Rational("-25")) == "-25"
-    assert str(Rational("25/7")) == "25/7"
-    assert str(Rational("-123/569")) == "-123/569"
-    assert str(Rational("1.25")) == "5/4"
-    assert str(Rational("-2.6e-2")) == "-13/500"
-    assert str(Rational("0.1[23]")) == "61/495"
-    assert str(Rational("5.1[666]")) == "31/6"
-    assert str(Rational("-5.1[666]")) == "-31/6"
-    assert str(Rational("0.[9]")) == "1"
-    assert str(Rational("-0.[9]")) == "-1"
+def test_Rational_new():
+    """"
+    Test for Rational constructor
+    """
+    n1 = Rational(1,2)
+    assert n1 == Rational(Integer(1), 2)
+    assert n1 == Rational(Integer(1), Integer(2))
+    assert n1 == Rational(1, Integer(2))
+
+    raises(ValueError, 'Rational(1.2)')
+    raises(ValueError, "Rational(Symbol('x'))")
+    raises(ValueError, 'Rational(Rational(1,2))')
 
 def test_Rational_cmp():
     n1 = Rational(1,4)
@@ -201,32 +179,19 @@ def test_powers():
     assert Rational(5**3, 8**3)**Rational(4,3) == Rational(5**4, 8**4)
     assert Rational(-4,7)**Rational(1,2) == I*Rational(4,7)**Rational(1,2)
 
-    assert str(Rational(1,4) ** Rational(1,2)) == "1/2"
-    assert str(Rational(1,36) ** Rational(1,2)) == "1/6"
-
-    assert str((123**25) ** Rational(1,25)) == "123"
-    assert str((123**25+1)**Rational(1,25)) != "123"
-    assert str((123**25-1)**Rational(1,25)) != "123"
-    assert str((123**25-1)**Rational(1,25)) != "122"
     assert sqrt(6) + sqrt(24) == 3*sqrt(6)
     assert sqrt(2) * sqrt(3) == sqrt(6)
     x = Symbol("x")
     assert sqrt(49*x) == 7*sqrt(x)
     assert sqrt((3-sqrt(pi))**2) == 3 - sqrt(pi)
     assert sqrt(Rational(1,2)) == Rational(1,2) * sqrt(2)
-    #assert str(Rational(3,5)**(-Rational(1,2))) == "5**(1/2)*(1/3)**(1/2)" #One that does not work
-    assert str(Rational(81,36)**(Rational(3,2))) == "27/8"
-    assert str(Rational(81,36)**(-Rational(3,2))) == "8/27"
-
-    assert str((-4)**Rational(1,2)) == str(2*I)
 
     # Test that this is fast
     assert integer_nthroot(2,10**10) == (1, False)
-    assert str(2**Rational(1,10**10)) == "2**(1/10000000000)"
 
 def test_abs1():
-    assert str(abs(Rational(1,6))) == "1/6"
-    assert str(abs(Rational(-1,6))) == "1/6"
+    assert Rational(1,6) != Rational(-1,6)
+    assert abs(Rational(1,6)) == abs(Rational(-1,6))
 
 def test_accept_int():
     assert Real(4) == 4
@@ -241,7 +206,7 @@ def test_int():
 
 def test_real_bug():
     x = Symbol("x")
-    assert str(2.0*x*x) in ["(2.0*x)*x","2.0*x**2"]
+    assert str(2.0*x*x) in ["(2.0*x)*x","2.0*x**2","2.00000000000000*x**2"]
     assert str(2.1*x*x)!="(2.0*x)*x"
 
 def test_bug_sqrt():
@@ -250,13 +215,13 @@ def test_bug_sqrt():
 def test_pi_Pi():
     "Test, that pi (instance) is imported, but Pi (class) is not"
     from sympy import pi
-    py.test.raises(ImportError, "from sympy import Pi")
+    raises(ImportError, "from sympy import Pi")
 
 def test_no_len():
     # there should be no len for numbers
-    py.test.raises(TypeError, "len(Rational(2))")
-    py.test.raises(TypeError, "len(Rational(2,3))")
-    py.test.raises(TypeError, "len(Integer(2))")
+    raises(TypeError, "len(Rational(2))")
+    raises(TypeError, "len(Rational(2,3))")
+    raises(TypeError, "len(Integer(2))")
 
 def test_issue222():
     assert sqrt(Rational(1, 5)) == Rational(1, 5)**S.Half
@@ -274,6 +239,89 @@ def test_issue324():
     assert sqrt(x-1) != I*(1-x)**Rational(1,2)
 
 def test_issue350():
-    x = Symbol("x")
+    x = Symbol("x", real=True)
     assert sqrt(x**2) == abs(x)
     assert sqrt(x-1).subs(x,5) == 2
+
+
+def test_Integer_factors():
+    def F(i):
+        return Integer(i).factors()
+
+    assert F(1)   == { 1:1}
+    assert F(2)   == { 2:1}
+    assert F(3)   == { 3:1}
+    assert F(4)   == { 2:2}
+    assert F(5)   == { 5:1}
+    assert F(6)   == { 2:1,  3:1}
+    assert F(7)   == { 7:1}
+    assert F(8)   == { 2:3}
+    assert F(9)   == { 3:2}
+    assert F(10)  == { 2:1,  5:1}
+    assert F(11)  == {11:1}
+    assert F(12)  == { 2:2,  3:1}
+    assert F(13)  == {13:1}
+    assert F(14)  == { 2:1,  7:1}
+    assert F(15)  == { 3:1,  5:1}
+    assert F(16)  == { 2:4}
+    assert F(17)  == {17:1}
+    assert F(18)  == { 2:1,  3:2}
+    assert F(19)  == {19:1}
+    assert F(20)  == { 2:2,  5:1}
+    assert F(21)  == { 3:1,  7:1}
+    assert F(22)  == { 2:1, 11:1}
+    assert F(23)  == {23:1}
+    assert F(24)  == { 2:3,  3:1}
+    assert F(25)  == { 5:2}
+    assert F(26)  == { 2:1, 13:1}
+    assert F(27)  == { 3:3}
+    assert F(28)  == { 2:2,  7:1}
+    assert F(29)  == {29:1}
+    assert F(30)  == { 2:1,  3:1,  5:1}
+    assert F(31)  == {31:1}
+    assert F(32)  == { 2:5}
+    assert F(33)  == { 3:1, 11:1}
+    assert F(34)  == { 2:1, 17:1}
+    assert F(35)  == { 5:1,  7:1}
+    assert F(36)  == { 2:2,  3:2}
+    assert F(37)  == {37:1}
+    assert F(38)  == { 2:1, 19:1}
+    assert F(39)  == { 3:1, 13:1}
+    assert F(40)  == { 2:3,  5:1}
+    assert F(41)  == {41:1}
+    assert F(42)  == { 2:1,  3:1,  7:1}
+    assert F(43)  == {43:1}
+    assert F(44)  == { 2:2, 11:1}
+    assert F(45)  == { 3:2,  5:1}
+    assert F(46)  == { 2:1, 23:1}
+    assert F(47)  == {47:1}
+    assert F(48)  == { 2:4,  3:1}
+    assert F(49)  == { 7:2}
+    assert F(50)  == { 2:1,  5:2}
+    assert F(51)  == { 3:1, 17:1}
+
+
+def test_Rational_factors():
+    def F(p,q):
+        return Rational(p,q).factors()
+
+    assert F(2,3)   == { 2:1, 3:-1}
+    assert F(2,9)   == { 2:1, 3:-2}
+    assert F(2,15)  == { 2:1, 3:-1, 5:-1}
+    assert F(6,10)  == { 3:1, 5:-1}
+
+    # TODO write more Rational.factor() tests
+
+
+def test_issue1008():
+    assert  pi*(E + 10) + pi*(-E - 10)          == 0
+    assert  pi*(E + 10**10) + pi*(-E - 10**10)  == 0
+    assert  pi*(E + 10**20) + pi*(-E - 10**20)  == 0
+    assert  pi*(E + 10**80) + pi*(-E - 10**80)  == 0
+
+
+def test_IntegerInteger():
+    a = Integer(4)
+    b = Integer(a)
+
+    assert a == b
