@@ -1,8 +1,7 @@
-from sympy import Symbol, exp, Integer, Real, sin, cos, log, Poly, Lambda, Function, I
+from sympy import Symbol, exp, Integer, Real, sin, cos, log, Poly, Lambda, \
+        Function, I, S, sqrt,  raises
 from sympy.abc import x, y
 from sympy.core.sympify import sympify, _sympify, _sympifyit, SympifyError
-import py
-#from sympy.utilities.pytest import XFAIL
 
 
 def test_439():
@@ -30,10 +29,11 @@ def test_sympify2():
 
 def test_sympify3():
     assert sympify("x**3") == x**3
+    assert sympify("x^3") == x**3
     assert sympify("1/2") == Integer(1)/2
 
-    py.test.raises(SympifyError, "_sympify('x**3')")
-    py.test.raises(SympifyError, "_sympify('1/2')")
+    raises(SympifyError, "_sympify('x**3')")
+    raises(SympifyError, "_sympify('1/2')")
 
 def test_sympify4():
     class A:
@@ -84,13 +84,14 @@ def test_bug496():
 
 def test_lambda():
     x = Symbol('x')
-    assert sympify('lambda : 1')==Lambda(x, 1)
-    assert sympify('lambda x: 2*x')==Lambda(x, 2*x)
+    assert sympify('lambda : 1') == Lambda(x, 1)
+    assert sympify('lambda x: 2*x') == Lambda(x, 2*x)
+    assert sympify('lambda x, y: 2*x+y') == Lambda([x, y], 2*x+y)
 
-    py.test.raises(SympifyError, "_sympify('lambda : 1')")
+    raises(SympifyError, "_sympify('lambda : 1')")
 
 def test_sympify_raises():
-    py.test.raises(SympifyError, sympify, "fx)")
+    raises(SympifyError, 'sympify("fx)")')
 
 
 def test__sympify():
@@ -112,8 +113,8 @@ def test__sympify():
     assert _sympify(a)      == Integer(5)
 
     # negative _sympify
-    py.test.raises(SympifyError, "_sympify('1')")
-    py.test.raises(SympifyError, "_sympify([1,2,3])")
+    raises(SympifyError, "_sympify('1')")
+    raises(SympifyError, "_sympify([1,2,3])")
 
 
 def test_sympifyit():
@@ -139,7 +140,7 @@ def test_sympifyit():
     assert add_raises(x, 0.5)   == x+Real('0.5')
     assert add_raises(x, y)     == x+y
 
-    py.test.raises(SympifyError, "add_raises(x, '1')")
+    raises(SympifyError, "add_raises(x, '1')")
 
 def test_int_float():
     class F1_1(object):
@@ -227,3 +228,20 @@ def test_int_float():
     assert abs(_sympify(f1_1) - 1.1) < 1e-5
     assert abs(_sympify(f1_1b) - 1.1) < 1e-5
     assert abs(_sympify(f1_1c) - 1.1) < 1e-5
+
+
+def test_issue1034():
+    a = sympify('Integer(4)')
+
+    assert a == Integer(4)
+    assert a.is_Integer
+
+def test_issue883():
+    a = [3,2.0]
+    assert sympify(a) == [Integer(3), Real(2.0)]
+    assert sympify(tuple(a)) == (Integer(3), Real(2.0))
+    assert sympify(set(a)) == set([Integer(3), Real(2.0)])
+
+def test_S_sympify():
+    assert S(1)/2 == sympify(1)/2
+    assert (-2)**(S(1)/2) == sqrt(2)*I
