@@ -1,14 +1,13 @@
 """Module providing the class Polynomial and low-level functions"""
 
-from sympy.core import *
+from sympy import Basic, Symbol, Pow, Number, Add, Mul, Integer, Rational, \
+        sympify, symbols, all
 # Use (faster) Singleton comparisons.
 from sympy.core.basic import S
 # Need numbers.gcd, for content.
 from sympy.core.numbers import igcd
 # To determine coefficient type:
 from sympy.core.numbers import NumberSymbol, ImaginaryUnit
-from sympy.utilities import *
-from sympy.core import sympify
 
 from sympy.polynomials import fast
 import sympy.polynomials    # for sympy.polynomials.wrapper  (cyclic)
@@ -69,6 +68,7 @@ class Polynomial(Basic):
         underlying SymPy expression.
 
     Examples:
+        >>> from sympy import *
         >>> x, y = symbols('xy')
         >>> f = Polynomial(x + 1)
         >>> f.sympy_expr
@@ -81,8 +81,8 @@ class Polynomial(Basic):
         'grevlex'
         >>> print f
         1 + x
-        >>> f
-        Polynomial(1 + x, ((1, 1), (1, 0)), [x], 'grevlex')
+        >>> print srepr(f)
+        Polynomial(Add(One, Symbol('x')), ((One, One), (One, Zero)), [Symbol('x')], 'grevlex')
         >>> g = Polynomial(y**2 - x*y)
         >>> s = f + g
         >>> s.var == [x, y]
@@ -207,18 +207,6 @@ class Polynomial(Basic):
         # This uses the Polynomial's attributes
         return object.__getattribute__(self, name)
 
-
-    def __str__(self):
-        """Return only the SymPy expression to be human-readable."""
-        return str(self.sympy_expr)
-
-
-    def __repr__(self):
-        """Returns a string that could be used to reconstruct this object."""
-        return "Polynomial(%s, %s, %s, %s)" % (repr(self.sympy_expr),
-                  repr(self.coeffs), repr(self.var), repr(self.order))
-
-
     def __eq__(self, other):
         """Equality is restricted to equality of SymPy expression.
 
@@ -485,12 +473,12 @@ class Polynomial(Basic):
             >>> print leadcoeff
             1/3
             >>> print f
-            (3/2)*x + (3/4)*y + x*y
+            3*x/2 + 3*y/4 + x*y
             >>> leadcoeff, f = f.as_monic()
             >>> print leadcoeff
             1
             >>> print f
-            (3/2)*x + (3/4)*y + x*y
+            3*x/2 + 3*y/4 + x*y
 
             >>> f = Polynomial(y*x, var=x)
             >>> leadcoeff, f = f.as_monic()
@@ -1030,5 +1018,3 @@ def IntPoly2Polynomial(f, var, order):
     for exp in exponents:
         coeffs.append((sympify(f[exp]), sympify(exp)))
     return Polynomial(coeffs=tuple(coeffs), var=var, order=order)
-
-
