@@ -1,8 +1,7 @@
-import py
 from sympy.utilities.pytest import XFAIL
 
 from sympy import pi, symbols, Symbol, Rational, \
-    S, Integer, I, cos, sin, Real, sqrt, sympify
+    S, Integer, I, cos, sin, Real, sqrt, sympify, raises
 
 from sympy.polynomials import Polynomial, PolynomialException,  \
     sqf_part, sqf, solve_system, roots, resultant, lcm, factor, \
@@ -17,8 +16,6 @@ def test_Polynomial():
     h = f + g
     assert f.var == [x]
     assert f.coeffs == ((1, 1), (2, 0))
-    assert str(f) == "2 + x"
-    assert repr(f) == "Polynomial(2 + x, ((1, 1), (2, 0)), [x], 'grevlex')"
     assert f == 2 + x
     assert f == Polynomial(None, f.coeffs, f.var, f.order)
     assert f.nth_coeff(0) == 2
@@ -62,8 +59,8 @@ def test_Polynomial():
                       var=[z, x, y], order='1-el').coeffs \
            == ((1, 1, 1, 0), (1, 0, 3, 1), (1, 0, 2, 2))
 
-    py.test.raises(PolynomialException, "Polynomial(sqrt(x),var=x)")
-    py.test.raises(PolynomialException, "Polynomial(sin(x),var=x)")
+    raises(PolynomialException, "Polynomial(sqrt(x),var=x)")
+    raises(PolynomialException, "Polynomial(sin(x),var=x)")
 
     assert 3*x**2 == Polynomial(coeffs=((Integer(3), Integer(2)),),
                                 var=x).sympy_expr
@@ -268,6 +265,8 @@ def test_resultant():
      assert b_res == s_res == ((a-c)*(b-c)).expand()
 
 def test_roots():
+    S = sympify
+
     a = Symbol("a")
     b = Symbol("b")
     c = Symbol("c")
@@ -288,13 +287,17 @@ def test_roots():
             -b/(a*2)-(((b/a)**2-4*c/a)**Rational(1,2))/2]
     assert roots(x**3 + x**2 + x + 1) == [-1, I, -I]
     assert roots(x**3 + x**2 - x + 1) in [
-           [Rational(-1,3) - (Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3) - Rational(4,9)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(-1,3),
-            Rational(-1,3) + Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3) + Rational(4,9)/(Rational(1,2) + Rational(1,2)*I*3**Rational(1,2))*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(-1,3) + Rational(1,2)*I*3**Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3),
-            Rational(-1,3) + Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3) + Rational(4,9)/(Rational(1,2) - Rational(1,2)*I*3**Rational(1,2))*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(-1,3) - Rational(1,2)*I*3**Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3)],
+           [S('-1/3 - (19/27 + 1/9*3**(1/2)*11**(1/2))**(1/3) - 4/9*(19/27 + 1/9*3**(1/2)*11**(1/2))**(-1/3)'),
+            S('-1/3 + 1/2*(19/27 + 1/9*3**(1/2)*11**(1/2))**(1/3) + 4/9/(1/2 + 1/2*I*3**(1/2))*(19/27 + 1/9*3**(1/2)*11**(1/2))**(-1/3) + 1/2*I*3**(1/2)*(19/27 + 1/9*3**(1/2)*11**(1/2))**(1/3)'),
+            S('-1/3 + (4/9)/(1/2 - 1/2*I*3**(1/2))*(19/27 + (1/9)*33**(1/2))**(-1/3) + (1/2)*(19/27 + (1/9)*33**(1/2))**(1/3) - 1/2*I*3**(1/2)*(19/27 + (1/9)*33**(1/2))**(1/3)')],
 
-           [Rational(-1,3) - (Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3) - Rational(4,9)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(-1,3),
-            Rational(-1,3) + Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3) - Rational(4,9)/(-Rational(1,2) - Rational(1,2)*I*3**Rational(1,2))*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(-1,3) + Rational(1,2)*I*3**Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3),
-            Rational(-1,3) + Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3) + Rational(4,9)/(Rational(1,2) - Rational(1,2)*I*3**Rational(1,2))*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(-1,3) - Rational(1,2)*I*3**Rational(1,2)*(Rational(19,27) + Rational(1,9)*3**Rational(1,2)*11**Rational(1,2))**Rational(1,3)],
+           [S('-1/3 - 4/9*(19/27 + (1/9)*33**(1/2))**(-1/3) - (19/27 + (1/9)*33**(1/2))**(1/3)'),
+            S('-1/3 + 4/9/(1/2 + (1/2)*I*3**(1/2))*(19/27 + (1/9)*33**(1/2))**(-1/3) + (1/2)*(19/27 + (1/9)*33**(1/2))**(1/3) + (1/2)*I*3**(1/2)*(19/27 + (1/9)*33**(1/2))**(1/3)'),
+            S('-1/3 + (4/9)/(1/2 - 1/2*I*3**(1/2))*(19/27 + (1/9)*33**(1/2))**(-1/3) + (1/2)*(19/27 + (1/9)*33**(1/2))**(1/3) - 1/2*I*3**(1/2)*(19/27 + (1/9)*33**(1/2))**(1/3)')],
+
+           [S('(-1/3) - 4/9*(19/27 + (1/9)*33**(1/2))**(-1/3) - (19/27 + (1/9)*33**(1/2))**(1/3)'),
+            S('-1/3 + (4/9)/(1/2 - 1/2*I*3**(1/2))*(19/27 + (1/9)*33**(1/2))**(-1/3) + (1/2)*(19/27 + (1/9)*33**(1/2))**(1/3) - 1/2*I*3**(1/2)*(19/27 + (1/9)*33**(1/2))**(1/3)'),
+            S('-1/3 + (4/9)/(1/2 + (1/2)*I*3**(1/2))*(19/27 + (1/9)*33**(1/2))**(-1/3) + (1/2)*(19/27 + (1/9)*33**(1/2))**(1/3) + (1/2)*I*3**(1/2)*(19/27 + (1/9)*33**(1/2))**(1/3)')],
                                             ]
 
     assert roots(x**4 - 1) == [1, I, -1, -I]
