@@ -1,14 +1,17 @@
+from sympy import symbols, expand, sin, sqrt, re, im, I, Rational, Lambda, \
+        powsimp, raises, Integer, Symbol, Poly, RootsOf, RootSum, RootOf, S
 
-from sympy import symbols, expand, sin, sqrt, re, im, I, Rational, Lambda, powsimp
+from sympy.polys.monomial import monomial_lex_cmp, monomial_grlex_cmp, \
+        monomial_grevlex_cmp, monomial_1_el_cmp
+from sympy.polys.algorithms import poly_groebner, poly_subresultants, \
+        poly_resultant, poly_half_gcdex, poly_gcdex, poly_gcd, poly_lcm, \
+        poly_pdiv
+from sympy.polys.rootfinding import poly_factors, roots_linear, \
+        roots_quadratic, roots_cubic, roots_binomial, roots_rational, roots, \
+        number_of_real_roots, poly_sturm, PolynomialError, poly_decompose, \
+        poly_sqf, poly_div, CoefficientError, SymbolsError
 
-from sympy.polys.monomial import *
-from sympy.polys.polynomial import *
-from sympy.polys.algorithms import *
-from sympy.polys.rootfinding import *
-
-import py
-
-a,b,c,x,y,z,u,v,t = symbols('abcxyzuvt')
+a,b,c,d,x,y,z,u,v,t = symbols('abcdxyzuvt')
 
 def test_monomial_cmp():
     assert monomial_lex_cmp((3,2,1), (1,2,4)) == 1
@@ -91,18 +94,18 @@ def test_poly_basics():
     assert Poly(Poly(x*y, x, y), order='lex') == \
         Poly(x*y, x, y, order='lex')
 
-    py.test.raises(SymbolsError, "Poly(x, 2)")
-    py.test.raises(SymbolsError, "Poly(x, 2*x)")
+    raises(SymbolsError, "Poly(x, 2)")
+    raises(SymbolsError, "Poly(x, 2*x)")
 
-    py.test.raises(SymbolsError, "Poly(x, 2, x)")
-    py.test.raises(SymbolsError, "Poly(x, 2*x, x)")
+    raises(SymbolsError, "Poly(x, 2, x)")
+    raises(SymbolsError, "Poly(x, 2*x, x)")
 
-    py.test.raises(SymbolsError, "Poly(x, x, 2)")
-    py.test.raises(SymbolsError, "Poly(x, x, 2*x)")
+    raises(SymbolsError, "Poly(x, x, 2)")
+    raises(SymbolsError, "Poly(x, x, 2*x)")
 
     A, B = symbols('AB', commutative=False)
 
-    py.test.raises(SymbolsError, "Poly(x + A**2 + B**2, x, A, B)")
+    raises(SymbolsError, "Poly(x + A**2 + B**2, x, A, B)")
 
 def test_poly_internals():
     p = Poly(x**2*y*z + x*y*z**3 + x*y + y*z, x, y, z)
@@ -145,52 +148,6 @@ def test_poly_internals():
     assert Poly._permute(q, z, y, x) == \
         {(0, 1, 1): 3, (1, 1, 0): 4, (3, 1, 1): 2, (1, 1, 2): 1}
 
-def test_poly_repr():
-    assert Poly(7, x).torepr() == \
-        "Poly([(Integer(7), (0,))], Symbol('x'), order='grlex')"
-
-    assert Poly(2*x*y + 7, x, y).torepr() == \
-        "Poly([(Integer(2), (1, 1)), (Integer(7), (0, 0))]," \
-        " Symbol('x'), Symbol('y'), order='grlex')"
-
-    assert Poly(2*x*y - 7, x, y, order='grevlex').torepr() == \
-        "Poly([(Integer(2), (1, 1)), (Integer(-7), (0, 0))]," \
-        " Symbol('x'), Symbol('y'), order='grevlex')"
-
-    assert Poly(0, x).tostr() == "Poly(0, x)"
-
-    assert Poly(1, x).tostr() == "Poly(1, x)"
-    assert Poly(x, x).tostr() == "Poly(x, x)"
-
-    assert Poly(2*x + 1, x).tostr() == "Poly(2*x + 1, x)"
-    assert Poly(2*x - 1, x).tostr() == "Poly(2*x - 1, x)"
-
-    assert Poly(-1, x).tostr() == "Poly(-1, x)"
-    assert Poly(-x, x).tostr() == "Poly(-x, x)"
-
-    assert Poly(-2*x + 1, x).tostr() == "Poly(-2*x + 1, x)"
-    assert Poly(-2*x - 1, x).tostr() == "Poly(-2*x - 1, x)"
-
-    assert Poly(x - 1, x, order='lex').tostr() == "Poly(x - 1, x)"
-
-    assert Poly(x**2 + 1 + y, x).tostr() == "Poly(x**2 + 1 + y, x)"
-    assert Poly(x**2 - 1 + y, x).tostr() in [
-            "Poly(x**2 - 1 + y, x)",
-            "Poly(x**2 + (-1) + y, x)",
-            ]
-
-    assert Poly(-x*y*z + x*y - 1, x, y, z).tostr() == "Poly(-x*y*z + x*y - 1, x, y, z)"
-
-    assert Poly(-t*x**21*y**7*z + (1 + t)*z**3 - 2*x*z + 1, x, y, z).tostr() == \
-        "Poly(-t*x**21*y**7*z + (1 + t)*z**3 - 2*x*z + 1, x, y, z)"
-
-    assert Poly(x*y*z**2 - 27*x, x, y, z, order='lex').tostr() == \
-        "Poly(x*y*z**2 - 27*x, x, y, z, order='lex')"
-    assert Poly(x*y*z**2 - 27*x, x, y, z, order='grlex').tostr() == \
-        "Poly(x*y*z**2 - 27*x, x, y, z)"
-    assert Poly(x*y*z**2 - 27*x, x, y, z, order='grevlex').tostr() == \
-        "Poly(x*y*z**2 - 27*x, x, y, z, order='grevlex')"
-
 def test_poly_cancel():
     assert Poly.cancel(x) == x
     assert Poly.cancel(x+1) == x+1
@@ -222,7 +179,7 @@ def test_poly_cancel():
 
     assert Poly.cancel(f) == -2 + sqrt(2)
 
-    py.test.raises(SymbolsError, "Poly.cancel((x**2-y**2, x-y))")
+    raises(SymbolsError, "Poly.cancel((x**2-y**2, x-y))")
 
 def test_poly_characteristics():
     f = -3*x**5*y*z**4 + 2*x**2*y**8 - x*y**4 + x*y*z**3
@@ -424,7 +381,7 @@ def test_as_integer():
     assert Poly(x**2 + x/2, x).as_integer() == \
         (Integer(2), Poly(2*x**2 + x, x))
 
-    py.test.raises(CoefficientError, "Poly(x**2 + t*x, x).as_integer()")
+    raises(CoefficientError, "Poly(x**2 + t*x, x).as_integer()")
 
 def test_poly_add():
     f = -Rational(1,6)*x**2-Rational(5,36)+Rational(17,18)
@@ -672,7 +629,7 @@ def test_map_coeffs():
 
     assert q.as_basic() == x**2*(I*im(u) + re(u)) + x*y*(I*im(v) + re(v))
 
-    py.test.raises(PolynomialError, "p.map_coeffs(lambda c: x*c)")
+    raises(PolynomialError, "p.map_coeffs(lambda c: x*c)")
 
 def test_coeff():
     p = Poly(3*x**2*y + 4*x*y**2 + 1, x, y)
@@ -701,7 +658,7 @@ def test_mul_div_term():
     assert f.mul_term(1) == Poly(x*y**2 + 2*y, x, y)
     assert f.mul_term(1, (0, 1)) == Poly(x*y**3 + 2*y**2, x, y)
 
-    py.test.raises(ZeroDivisionError, "f.div_term(0)")
+    raises(ZeroDivisionError, "f.div_term(0)")
 
     assert f.div_term(1) == Poly(x*y**2 + 2*y, x, y)
     assert f.div_term(1, (0, 1)) == Poly(x*y + 2, x, y)
@@ -826,7 +783,7 @@ def test_evaluate():
     assert p.evaluate({y: 0}) == \
         Poly(x**2, x, order='lex')
 
-    py.test.raises(PolynomialError, "Poly(x + y, x, y).evaluate({x: y})")
+    raises(PolynomialError, "Poly(x + y, x, y).evaluate({x: y})")
 
 def test_subs():
     p = Poly(t*x*y**2 + x*y + t**2, x, y)
@@ -963,8 +920,8 @@ def test_number_of_real_roots():
     assert number_of_real_roots(f, x, sup=0) == 1
     assert number_of_real_roots(f, x, inf=-1, sup=1) == 0
 
-    py.test.raises(ValueError, "number_of_real_roots(f, x, inf=t)")
-    py.test.raises(ValueError, "number_of_real_roots(f, x, sup=t)")
+    raises(ValueError, "number_of_real_roots(f, x, inf=t)")
+    raises(ValueError, "number_of_real_roots(f, x, sup=t)")
 
 def test_roots():
     assert roots_linear(Poly(2*x+1, x)) == [-Rational(1, 2)]
@@ -991,8 +948,11 @@ def test_roots():
     assert roots_binomial(Poly(5*x**4+2, x)) == \
         [A+I*A, -A+I*A, -A-I*A, A-I*A]
 
-    r0 = roots_quadratic(Poly(a*x**2 + b, x))
-    r1 = roots_binomial(Poly(a*x**2 + b, x))
+    a1 = Symbol('a1', nonnegative=True)
+    b1 = Symbol('b1', nonnegative=True)
+
+    r0 = roots_quadratic(Poly(a1*x**2 + b1, x))
+    r1 = roots_binomial(Poly(a1*x**2 + b1, x))
 
     assert powsimp(r0[0]) == powsimp(r1[0])
     assert powsimp(r0[1]) == powsimp(r1[1])
@@ -1042,6 +1002,9 @@ def test_roots():
         S.One: 1, -S.One: 1, I: 1, -I: 1
     }
 
+    assert roots((a+b+c)*x + a+b+c+d, x) == \
+        { (-a-b-c-d) / (a+b+c) : 1 }
+
     assert roots(x**3+x**2-x+1, x, cubics=False) == {}
 
     r1_2, r1_3, r1_9, r4_9, r19_27 = [ Rational(*r) \
@@ -1159,11 +1122,4 @@ def test_RootsOf():
     assert RootSum(Lambda(x, x), Poly(0, x), evaluate=True)  == S.Zero
     assert RootSum(Lambda(x, x), Poly(0, x), evaluate=False) != S.Zero
 
-    f = Poly(x**17 + x - 1, x)
-
-    assert RootsOf(f).tostr() == "RootsOf(x**17 + x - 1, x)"
-
-    assert RootOf(f, 0).tostr() == "RootOf(x**17 + x - 1, x, index=0)"
-
-    assert RootSum(Lambda(z, z**2), f).tostr() == \
-        "RootSum(Lambda(_z, _z**2), x**17 + x - 1, x)"
+    assert RootSum(Lambda(x, x), Poly(x-1, x), evaluate=False).doit() == S.One
