@@ -87,10 +87,46 @@ the bugs are usually in the series expansion (i.e. in SymPy) or in rewrite.
 
 This code is almost exact rewrite of the Maple code inside the Gruntz thesis.
 
+Debugging
+---------
+
+Because the gruntz algorithm is highly recursive, it's difficult to figure out
+what went wrong inside a debugger. Instead, turn on nice debug prints by
+applying the following patch:
+
+@@ -101,7 +108,7 @@ def debug(func):
+     It will print a nice execution tree with arguments and results
+     of all decorated functions.
+     ""
+-    if 1:
++    if 0:
+         #normal mode - do nothing
+         return func
+
+Then start isympy and type the failing limit. For example:
+
+In [1]: limit(sin(x)/x, x, 0)
+limitinf(_x*sin(1/_x), _x) = 1
++-mrv_leadterm(_x*sin(1/_x), _x) = (1, 0)
+| +-mrv(_x*sin(1/_x), _x) = set([_x])
+| | +-mrv(_x, _x) = set([_x])
+| | +-mrv(sin(1/_x), _x) = set([_x])
+| |   +-mrv(1/_x, _x) = set([_x])
+| |     +-mrv(_x, _x) = set([_x])
+| +-mrv_leadterm(exp(_x)*sin(exp(-_x)), _x, set([exp(_x)])) = (1, 0)
+|   +-rewrite(exp(_x)*sin(exp(-_x)), set([exp(_x)]), _x, _w) = (1/_w*sin(_w), -_x)
+|     +-sign(_x, _x) = 1
+|     +-mrv_leadterm(1, _x) = (1, 0)
++-sign(0, _x) = 0
++-limitinf(1, _x) = 1
+
+And check manually which line is wrong. Then go to the source code and debug
+this function to figure out the exact problem.
+
 """
 
-from sympy.core import Basic, S, Add, Mul, Pow, Function, oo, Symbol, Rational, \
-        Real, sympify
+from sympy.core import Basic, S, Add, Mul, Pow, Function, oo, Symbol, \
+        Rational, Real, sympify, C, I
 from sympy.functions import log, exp
 from sympy.series.order import Order
 O = Order
@@ -276,8 +312,7 @@ def sign(e, x):
         else:
             return -1
     elif not e.has(x):
-        f= e.evalf()
-        if f > 0:
+        if e.is_positive:
             return 1
         else:
             return -1
@@ -308,6 +343,8 @@ def limitinf(e, x):
     sig=sign(e0,x)
     if sig==1: return S.Zero # e0>0: lim f = 0
     elif sig==-1: #e0<0: lim f = +-oo   (the sign depends on the sign of c0)
+        if c0.match(I*C.Wild("a", exclude=[I])):
+            return c0*oo
         s = sign(c0, x)
         #the leading term shouldn't be 0:
         assert s != 0
@@ -331,63 +368,23 @@ def subexp(e,sub):
 def calculate_series(e, x):
     """ Calculates at least one term of the series of "e" in "x".
 
-    This is a place that fails most often, so it is made robust so that
-    meaningful errors are printed out in case of problems.
+    This is a place that fails most often, so it is in it's own function.
     """
-    def report(f, x):
-        print "The limit algorithm needs to calculate the series of"
-        print "series:", f
-        print "expansion variable (expanding around 0+):", x
-        print """\
-But the series expansion failed. Check that this series is meaningful and make
-it work, then run this again. If the series cannot be mathematically calculated, the bug is in the limit algorithm."""
-        raise NotImplementedError("The underlying series facility failed (read the messages printed to stdout for more information)")
 
-    #First do some simplification (the oseries can fail otherwise). Better
-    #solution is to fix oseries, so that it works for any expression.
-    f = e.expand().normal()
-    try:
-        series=f.nseries(x, 0, 2).removeO()
-        if series == 0:
-            #we need to calculate more terms, let's try 4:
-            series=f.nseries(x, 0, 4).removeO()
-        if series == 0:
-            #we need to calculate more terms, let's try 10:
-            series=f.nseries(x, 0, 6).removeO()
-        if series == 0:
-            #we need to calculate more terms, let's try 30:
-            series=f.nseries(x, 0, 8).removeO()
-    except:
-        import traceback
-        traceback.print_exc()
-        report(f, x)
+    f = e
+    series=f.nseries(x, 0, 2).removeO()
     if series == 0:
-        report(f, x)
+        #we need to calculate more terms, let's try 4:
+        series=f.nseries(x, 0, 4).removeO()
+    if series == 0:
+        #we need to calculate more terms, let's try 6:
+        series=f.nseries(x, 0, 6).removeO()
+    if series == 0:
+        #we need to calculate more terms, let's try 8:
+        series=f.nseries(x, 0, 8).removeO()
     assert not isinstance(series, O), f
     return series
 
-def calculate_leadterm(e, x):
-    """ Calculates the leadterm of "e" in "x".
-
-    Make a nice report if it fails, that signals a bug either in limits or
-    series expansion.
-    """
-
-    def report(f, x):
-        print "The limit algorithm needs to calculate the leadterm of"
-        print "series:", f
-        print "expansion variable (expanding around 0+):", x
-        print """\
-But the leadterm() method failed. Check that this series is meaningful and make
-it work, then run this again. If the leadterm() cannot be mathematically
-calculated, the bug is in the limit algorithm."""
-        raise NotImplementedError("The underlying series facility failed (read the messages printed to stdout for more information)")
-
-    try:
-        return e.leadterm(x)
-    except:
-        report(e, x)
-
 @debug
 def mrv_leadterm(e, x, Omega=[]):
     """Returns (c0, e0) for e."""
@@ -407,11 +404,11 @@ def mrv_leadterm(e, x, Omega=[]):
     # in the algorithm). For limits of complex functions, the algorithm would
     # have to be improved, or just use limits of Re and Im components
     # separately.
-    wsym = Symbol("w", real=True, dummy=True)
+    wsym = Symbol("w", real=True, positive=True, dummy=True)
     f, logw=rewrite(e, set(Omega), x, wsym)
     series = calculate_series(f, wsym)
     series=series.subs(log(wsym), logw)
-    return calculate_leadterm(series, wsym)
+    return series.leadterm(wsym)
 
 
 #this class is not yet adapted for the new core.
