@@ -21,7 +21,7 @@ from sympy.core.function import Derivative, diff
 
 from sympy.functions import sqrt, log, exp, LambertW
 from sympy.simplify import simplify, collect
-from sympy.matrices import Matrix, zeronm
+from sympy.matrices import Matrix, zeros
 from sympy.polys import roots
 
 from sympy.utilities import any, all
@@ -54,12 +54,12 @@ def solve(f, *symbols, **flags):
        Solve a polynomial equation:
 
        >>> solve(x**4-1, x)
-       [I, 1, -1, -I]
+       [1, -1, -I, I]
 
        Solve a linear system:
 
        >>> solve((x+5*y-2, -3*x+6*y-15), x, y)
-       {y: 1, x: -3}
+       {x: -3, y: 1}
 
     """
     if not symbols:
@@ -115,7 +115,7 @@ def solve(f, *symbols, **flags):
 
             if all(p.is_linear for p in polys):
                 n, m = len(f), len(symbols)
-                matrix = zeronm(n, m + 1)
+                matrix = zeros((n, m + 1))
 
                 for i, poly in enumerate(polys):
                     for coeff, monom in poly.iter_terms():
@@ -159,7 +159,7 @@ def solve_linear_system(system, *symbols, **flags):
 
        >>> system = Matrix(( (1, 4, 2), (-2, 1, 14)))
        >>> solve_linear_system(system, x, y)
-       {y: 2, x: -6}
+       {x: -6, y: 2}
 
     """
     matrix = system[:,:]
@@ -168,14 +168,23 @@ def solve_linear_system(system, *symbols, **flags):
     i, m = 0, matrix.cols-1  # don't count augmentation
 
     while i < matrix.lines:
-        if matrix [i, i] == 0:
+        if i == m:
+            # an overdetermined system
+            if any(matrix[i:,m]):
+                return None   # no solutions
+            else:
+                # remove trailing rows
+                matrix = matrix[:i,:]
+                break
+
+        if not matrix[i, i]:
             # there is no pivot in current column
             # so try to find one in other colums
-            for k in range(i+1, m):
-                if matrix[i, k] != 0:
+            for k in xrange(i+1, m):
+                if matrix[i, k]:
                     break
             else:
-                if matrix[i, m] != 0:
+                if matrix[i, m]:
                     return None   # no solutions
                 else:
                     # zero row or was a linear combination of
@@ -188,18 +197,18 @@ def solve_linear_system(system, *symbols, **flags):
             syms[i], syms[k] = syms[k], syms[i]
             matrix.col_swap(i, k)
 
-        pivot = matrix [i, i]
+        pivot_inv = S.One / matrix [i, i]
 
         # divide all elements in the current row by the pivot
-        matrix.row(i, lambda x, _: x / pivot)
+        matrix.row(i, lambda x, _: x * pivot_inv)
 
-        for k in range(i+1, matrix.lines):
-            if matrix[k, i] != 0:
+        for k in xrange(i+1, matrix.lines):
+            if matrix[k, i]:
                 coeff = matrix[k, i]
 
                 # subtract from the current row the row containing
                 # pivot and multiplied by extracted coefficient
-                matrix.row(k, lambda x, j: x - matrix[i, j]*coeff)
+                matrix.row(k, lambda x, j: simplify(x - matrix[i, j]*coeff))
 
         i += 1
 
@@ -218,7 +227,7 @@ def solve_linear_system(system, *symbols, **flags):
             content = matrix[k, m]
 
             # run back-substitution for variables
-            for j in range(k+1, m):
+            for j in xrange(k+1, m):
                 content -= matrix[k, j]*solutions[syms[j]]
 
             if simplified:
@@ -238,11 +247,11 @@ def solve_linear_system(system, *symbols, **flags):
             content = matrix[k, m]
 
             # run back-substitution for variables
-            for j in range(k+1, i):
+            for j in xrange(k+1, i):
                 content -= matrix[k, j]*solutions[syms[j]]
 
             # run back-substitution for parameters
-            for j in range(i, m):
+            for j in xrange(i, m):
                 content -= matrix[k, j]*syms[j]
 
             if simplified:
@@ -270,10 +279,10 @@ def solve_undetermined_coeffs(equ, coeffs, sym, **flags):
        >>> a, b, c, x = symbols('a', 'b', 'c', 'x')
 
        >>> solve_undetermined_coeffs(Eq(2*a*x + a+b, x), [a, b], x)
-       {b: -1/2, a: 1/2}
+       {a: 1/2, b: -1/2}
 
        >>> solve_undetermined_coeffs(Eq(a*c*x + a+b, x), [a, b], x)
-       {b: -1/c, a: 1/c}
+       {a: 1/c, b: -1/c}
 
     """
     if isinstance(equ, Equality):
@@ -418,7 +427,7 @@ def solve_ODE_first_order(eq, f):
 
     #other cases of first order odes will be implemented here
 
-    raise NotImplementedError("dsolve: Cannot solve " + str(eq))
+    raise NotImplementedError("solve_ODE_first_order: Cannot solve " + str(eq))
 
 def solve_ODE_second_order(eq, f):
     """
@@ -474,7 +483,7 @@ def solve_ODE_second_order(eq, f):
         #assert ( t.diff(x,2)*r[a]/t ).expand() == eq
         return solve_ODE_1(f(x), x)
 
-    raise NotImplementedError("cannot solve this")
+    raise NotImplementedError("solve_ODE_second_order: cannot solve " + str(eq))
 
 def solve_ODE_1(f, x):
     """ (x*exp(-f(x)))'' = 0 """
@@ -521,10 +530,10 @@ def tsolve(eq, sym):
         >>> x = Symbol('x')
 
         >>> tsolve(3**(2*x+5)-4, x)
-        (1/2)/log(3)*(-5*log(3) + log(4))
+        (-5*log(3) + log(4))/(2*log(3))
 
         >>> tsolve(log(x) + 2*x, x)
-        (1/2)*LambertW(2)
+        1/2*LambertW(2)
 
     """
     if patterns is None:
@@ -545,6 +554,76 @@ def tsolve(eq, sym):
         m = eq2.match(p)
         if m:
             return sol.subs(m).subs(x, sym)
+
+    # let's also try to inverse the equation
+    lhs = eq
+    rhs = S.Zero
+
+    while True:
+        indep, dep = lhs.as_independent(sym)
+
+        # dep + indep == rhs
+        if lhs.is_Add:
+            # this indicates we have done it all
+            if indep is S.Zero:
+                break
+
+            lhs = dep
+            rhs-= indep
+
+        # dep * indep == rhs
+        else:
+            # this indicates we have done it all
+            if indep is S.One:
+                break
+
+            lhs = dep
+            rhs/= indep
+
+    #                    -1
+    # f(x) = g  ->  x = f  (g)
+    if lhs.is_Function and lhs.nargs==1 and hasattr(lhs, 'inverse'):
+        rhs = lhs.inverse() (rhs)
+        lhs = lhs.args[0]
+
+        sol = solve(lhs-rhs, sym)
+        return sol[0]
+
+    elif lhs.is_Add:
+        # just a simple case - we do variable substitution for first function,
+        # and if it removes all functions - let's call solve.
+        #      x    -x                   -1
+        # UC: e  + e   = y      ->  t + t   = y
+        t = Symbol('t', dummy=True)
+        terms = lhs.args
+
+        # find first term which is Function
+        for f1 in lhs.args:
+            if f1.is_Function:
+                break
+        else:
+            assert False, 'tsolve: at least one Function expected at this point'
+
+        # perform the substitution
+        lhs_ = lhs.subs(f1, t)
+
+        # if no Functions left, we can proceed with usual solve
+        if not (lhs_.is_Function or
+                any(term.is_Function for term in lhs_.args)):
+
+            # FIXME at present solve cannot solve x + 1/x = y
+            # FIXME so we do this:
+            numer, denom = lhs_.as_numer_denom()
+            sol = solve(numer-rhs*denom, t)
+           #sol = solve(lhs_-rhs, t)
+            sol = sol[0]
+
+            sol = tsolve(sol-f1, sym)
+            return sol
+
+
+
+
     raise ValueError("unable to solve the equation")
 
 
