@@ -14,3 +14,7 @@ from lambdify import lambdify
 from source import source
 
 from decorator import threaded
+
+from runtests import test
+
+from pytest import raises
